@@ -1,11 +1,11 @@
 #!/bin/sh
 set -e
-export TAR_OPTIONS='--owner root --group root --mode a+rX'
+export TAR_OPTIONS='--owner root --group root --mode a+rX --format ustar'
 export GZIP_OPTIONS='-9n'
 set -x
 destdir=$1
-[ -z "$destdir" ] && destdir=$(shell pwd)
-tmpdir=$(mktemp -d)
+[ -z "$destdir" ] && destdir=$(pwd)
+tmpdir=$(mktemp -d -t openinbrowser.get-orig-source.XXXXXX)
 uscan --no-conf --verbose --force-download --destdir "$tmpdir"
 (
     cd "$tmpdir"
